summaryrefslogtreecommitdiffstatshomepage
path: root/examples/hwapi
diff options
context:
space:
mode:
Diffstat (limited to 'examples/hwapi')
-rw-r--r--examples/hwapi/hwconfig_esp8266_esp12.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/hwapi/hwconfig_esp8266_esp12.py b/examples/hwapi/hwconfig_esp8266_esp12.py
index e8cf2d12e1..fb6d5fe907 100644
--- a/examples/hwapi/hwconfig_esp8266_esp12.py
+++ b/examples/hwapi/hwconfig_esp8266_esp12.py
@@ -1,5 +1,5 @@
-from machine import Pin
+from machine import Pin, Signal
# ESP12 module as used by many boards
-# Blue LED on pin 2
-LED = Pin(2, Pin.OUT)
+# Blue LED on pin 2, active low (inverted)
+LED = Signal(Pin(2, Pin.OUT), inverted=True)